<?php
/**
 * Sample implementation of the Custom Header feature.
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package Theme Palace
 * @subpackage Travel Base Pro
 * @since Travel Base Pro 1.0.0
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses travel_base_pro_header_style()
 */
function travel_base_pro_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'travel_base_pro_custom_header_args', array(
		'default-image'          => '%s/assets/uploads/header-image.jpg',
		'default-text-color'     => '181818',
		'width'                  => 1200,
		'height'                 => 528,
		'flex-height'            => true,
		'wp-head-callback'       => 'travel_base_pro_header_style',
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/assets/uploads/header-image.jpg',
			'thumbnail_url' => '%s/assets/uploads/header-image.jpg',
			'description'   => esc_html__( 'Default Header Image', 'travel-base-pro' ),
		),
	) );
}
add_action( 'after_setup_theme', 'travel_base_pro_custom_header_setup' );

if ( ! function_exists( 'travel_base_pro_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog.
	 *
	 * @see travel_base_pro_custom_header_setup().
	 */
	function travel_base_pro_header_style() {
		$options = travel_base_pro_get_theme_options();
		$css = '';

		$header_title_color = $options['header_title_color'];
		$header_tagline_color = $options['header_tagline_color'];

		$h1_h6_font_family = explode( '-', $options['theme_typography'] );
		$h1_h6_font_family = implode( ' ', array_map( 'ucfirst', $h1_h6_font_family ) );
		
		$body_font_family = explode( '-', $options['body_theme_typography'] );
		$body_font_family = implode( ' ', array_map( 'ucfirst', $body_font_family ) );

		/*
		 * If no custom options for text are set, let's bail.
		 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: HEADER_TEXTCOLOR.
		 */
		if ( $header_title_color && $header_tagline_color ) {

			// If we get this far, we have custom styles. Let's do this.
			// Has the text been hidden?
			if ( ! display_header_text() ) :
			$css .='
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
			}';

			// If the user has set a custom color for the text use that.
			else :
			$css .='
			.site-title a {
				color: '.esc_attr( $header_title_color ).';
			}
			.site-description {
				color: '.esc_attr( $header_tagline_color ).';
			}';
			endif;
		}

		$pagination_type = isset( $options['pagination_type'] ) ? $options['pagination_type'] : 'default';
		if ( $pagination_type == 'infinite' ) {
			$css .= '
			.site-main nav.pagination.navigation {
				display:none;
			}';
		}

		$css .= '.trail-items li:not(:last-child):after {
			    content: "' . html_entity_decode( esc_attr( $options['breadcrumb_separator'] ) ) . '";
			    padding: 0 5px;
			}';
		
		$css .=	'
				/*--------------------------------------------------------------
				#  Posts Title Font Family
				--------------------------------------------------------------*/
				h1,
				h2,
				h3,
				h4,
				h5,
				h6,
				#top-bar .contact-info a,
				#our-services .more-link,
				.wp-travel-filter p label,
				.wp-travel-filter form input[type="submit"],
				.trip-price,
				.destination-item-wrapper .more-link,
				#latest-posts .posted-on a,
				.travel-info .title {
				    font-family: ' . esc_attr( $h1_h6_font_family ) . ', serif;
				}

				/*--------------------------------------------------------------
				#  Body Font Family
				--------------------------------------------------------------*/

				body,
				.site-title,
				#featured-tours .btn .current-price,
				#featured-tours .btn .trip-price,
				.wp-travel-trip-code code {
				    font-family: ' . esc_attr( $body_font_family ) . ', sans-serif;
				}
				';

		wp_add_inline_style( 'travel-base-pro-style', $css );
	}
endif;
add_action( 'wp_enqueue_scripts', 'travel_base_pro_header_style', 10 );